Gritter demo for jQuery - boedesign.com

# Gritter Demo

The super awesome background is just to show you that all notifications are transparent! Tested in: FF 3+, Opera 9, IE7, IE8, Safari 4+

- Add regular notification: Fades out after a certain amount of time, can be set for each notification.
- Add sticky notification: Doesn't run on a fade timer. Just sits there until the user manually removes it by clicking on the (X)
- Add notification without image
- Add notification (with callbacks)
- Add a sticky notification (with callbacks)
- Remove all notifications
- Remove all notifications (with callbacks)